@@ -1,4 +1,5 @@
 package Feersum::Connection::Handle;
+use warnings;
 use strict;
 
 sub new {
@@ -6,20 +7,24 @@ sub new {
 }
 
 package Feersum::Connection::Reader;
+use warnings;
 use strict;
 use base 'Feersum::Connection::Handle';
 
-sub write { Carp::croak "can't call write() on a read-only handle" }
+sub write { ## no critic (BuiltinHomonyms)
+    Carp::croak "can't call write() on a read-only handle" }
 
 package Feersum::Connection::Writer;
+use warnings;
 use strict;
 use base 'Feersum::Connection::Handle';
 
-sub read { Carp::croak "can't call read() on a write-only handle" }
-sub seek { Carp::croak "can't call seek() on a write-only handle" }
+sub read { ## no critic (BuiltinHomonyms)
+    Carp::croak "can't call read() on a write-only handle" }
+sub seek { ## no critic (BuiltinHomonyms)
+    Carp::croak "can't call seek() on a write-only handle" }
 
 package Feersum::Connection::Handle;
-
 1;
 __END__
 
@@ -154,6 +159,14 @@ to prevent a circular reference.
 
 Methods in common to both types of handles.
 
+=begin comment
+
+=item C<< Feersum::Connection::Handle->new() >>
+
+Shouldn't be called directly; L<Feersum> will create these objects.
+
+=end comment
+
 =over 4
 
 =item C<< $h->response_guard($guard) >>
@@ -167,6 +180,10 @@ the response.
 
 C<psgix.output.guard> is the PSGI-env extension that indicates this method.
 
+=item C<< $h->fileno >>
+
+Returns the file descriptor number for this connection.
+
 =back
 
 =head1 AUTHOR
